@@ -119,14 +119,14 @@ class TaskScheduler(object):
 
     def add_job(self, job):
         if self.redis.hexists(self.jobs_key, job.id):
-            raise ConflictingIdError(job.id)
+            return
         self.redis.hset(self.jobs_key, job.id, pickle.dumps(job.__getstate__(), self.pickle_protocol))
         if job.next_run_time:
             self.redis.zadd(self.run_times_key, {job.id: datetime_to_utc_timestamp(job.next_run_time)})
 
     def update_job(self, job):
         if not self.redis.hexists(self.jobs_key, job.id):
-            raise JobLookupError(job.id)
+            return
         self.redis.hset(self.jobs_key, job.id, pickle.dumps(job.__getstate__(), self.pickle_protocol))
         if job.next_run_time:
             self.redis.zadd(self.run_times_key,
@@ -136,7 +136,7 @@ class TaskScheduler(object):
 
     def remove_job(self, job_id):
         if not self.redis.hexists(self.jobs_key, job_id):
-            raise JobLookupError(job_id)
+            return
         self.redis.hdel(self.jobs_key, job_id)
         self.redis.zrem(self.run_times_key, job_id)
 
